"use strict";

require("jest-localstorage-mock");

var _react = _interopRequireDefault(require("react"));

var _ = _interopRequireWildcard(require("."));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.useFakeTimers();
jest.spyOn(_react.default, 'useState').mockImplementation(v => [v, jest.fn()]);
jest.spyOn(_react.default, 'useEffect').mockImplementation(v => v());
jest.spyOn(_react.default, 'useCallback').mockImplementation(v => v);
beforeAll(() => {
  Object.defineProperty(window.location, 'reload', {
    writable: true
  });
  window.location.reload = jest.fn();
});
describe('useLoading axios hook', () => {
  describe('requestHandler', () => {
    const req = {
      headers: {
        common: {}
      },
      baseURL: 'localhost',
      url: '/foo'
    };
    it('should query localStorage API', () => {
      (0, _.handleRequest)(req);
      expect(localStorage.getItem).toHaveBeenCalledWith('localhost/foo');
    });
    it('should attach etag headers', () => {
      localStorage.getItem.mockReturnValue(JSON.stringify({
        'Last-Modified': 2,
        ETag: 1,
        data: {}
      }));
      (0, _.handleRequest)(req);
      expect(req.headers.common).toMatchObject({
        'If-Match': 1,
        'If-Unmodified-Since': 2
      });
    });
  });
  describe('handleResponse', () => {
    const res = {
      data: {
        foo: 'bar'
      },
      headers: {
        ETag: 1,
        'Last-Modified': 2
      },
      config: {
        url: '/path'
      }
    };
    it.skip('should set localStorage', () => {
      (0, _.handleResponse)(res).set();
      expect(localStorage.setItem).toHaveBeenCalledWith('/path', JSON.stringify({
        data: {
          foo: 'bar'
        },
        ETag: 1,
        'Last-Modified': 2
      }));
    });
    it('should call onSuccess', () => {
      const stub = {
        onSuccess: jest.fn()
      };
      const message = 'Yup!';
      (0, _.handleResponse)({
        config: {
          method: 'POST'
        },
        status: 200,
        data: {
          message
        }
      }).notify(stub);
      expect(stub.onSuccess).toHaveBeenCalledWith('Yup!');
    });
    it('should not call onSuccess', () => {
      const stub = {
        onSuccess: jest.fn()
      };
      (0, _.handleResponse)({
        config: {
          method: 'GET'
        },
        status: 200,
        data: {
          message: ''
        }
      }).notify(stub);
      expect(stub.onSuccess).not.toHaveBeenCalledWith();
    });
    it.skip('should call onFail', () => {
      const stub = {
        onFail: jest.fn()
      };
      const message = 'Nope!';
      (0, _.handleResponse)({
        config: {
          method: 'GET'
        },
        status: 404,
        data: {
          message
        }
      }).notify(stub);
      expect(stub.onFail).toHaveBeenCalledWith(message);
    });
  });
  describe('handleError', () => {
    it.skip('should call onFail on 412', () => {
      const stub = {
        onFail: jest.fn()
      };
      (0, _.handleError)({
        response: {
          config: {},
          status: 412
        }
      }).notify(stub);
      expect(stub.onFail).toHaveBeenCalledWith(expect.any(String));
    });
  });
  it.skip('should resolve from cache', () => {
    const stub = {
      stuff: true
    };
    localStorage.getItem.mockReturnValue(JSON.stringify(stub));
    return expect((0, _.handleError)({
      response: {
        config: {
          method: 'get'
        },
        status: 304
      }
    }).refresh()).resolves.toMatchObject(stub);
  });
  it.skip('should call refresh', async () => {
    const stub = {
      response: {
        config: {},
        status: 304
      }
    };
    localStorage.getItem.mockReturnValue(null);
    await expect((0, _.handleError)(stub).refresh()).rejects.toMatchObject(stub);
    expect(setTimeout).toHaveBeenCalledTimes(1);
  });
  describe('useLoading default export', () => {
    it.skip('should default to false', () => expect((0, _.default)()).toBeFalsy());
  });
});