"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestMockAxios = _interopRequireDefault(require("jest-mock-axios"));

var _constants = require("../constants");

var _actions = _interopRequireDefault(require("../actions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dispatch = jest.fn();
let spy;
beforeAll(() => {
  spy = jest.spyOn(_react.default, 'useReducer').mockImplementation((_, init) => [init, dispatch]);
  jest.spyOn(_react.default, 'useEffect').mockImplementation(fn => fn());
});
beforeEach(() => {
  dispatch.mockReset();
});
describe('useRest', () => {
  let get;
  let post;
  let put;
  let patch;
  let remove;
  beforeAll(() => {
    ({
      get,
      post,
      put,
      patch,
      remove
    } = (0, _actions.default)({
      url: '/foo',
      decorators: {
        post: (v = {}) => Object.assign(v, {
          modified: true
        })
      }
    }));
  });
  beforeEach(() => {
    spy.mockClear();
  });
  it('should fetch into state', () => {
    const resp = {
      data: {
        resource: 1
      }
    };
    get('?search=foo');
    expect(_jestMockAxios.default.get).toHaveBeenCalledWith('/foo?search=foo');

    _jestMockAxios.default.mockResponse(resp);

    expect(dispatch.mock.calls).toHaveLength(2);
    expect(dispatch.mock.calls[1]).toEqual([expect.objectContaining({ ...resp,
      type: _constants.FETCHED
    })]);
  });
  it('should fail to fetch', () => {
    get();
    expect(_jestMockAxios.default.get).toHaveBeenCalledWith('/foo');

    _jestMockAxios.default.mockError({
      message: 'Whoops'
    });

    expect(dispatch).toHaveBeenCalledWith({
      type: _constants.FETCHED,
      err: expect.any(Object),
      data: expect.any(Object)
    });
  });
  it('should fail to fetch', () => {
    get();
    expect(_jestMockAxios.default.get).toHaveBeenCalledWith('/foo');

    _jestMockAxios.default.mockError({
      message: 'Whoops'
    });
  });
  it('should delete by ID', () => {
    remove(1)();
    expect(_jestMockAxios.default.delete).toHaveBeenCalledWith('/foo/1');

    _jestMockAxios.default.mockResponse();

    expect(dispatch).toHaveBeenCalledWith(expect.objectContaining({
      type: _constants.DELETED
    }));
  });
  it('should put by ID', () => {
    put(1)({});
    expect(_jestMockAxios.default.put).toHaveBeenCalledWith('/foo/1', expect.any(Object));

    _jestMockAxios.default.mockResponse({
      data: {
        bar: 1
      }
    });

    expect(dispatch).toHaveBeenCalledWith(expect.objectContaining({
      type: _constants.UPDATED,
      data: {
        bar: 1
      }
    }));
  });
  it('should fail to patch', () => {
    put(1)({});
    expect(_jestMockAxios.default.put).toHaveBeenCalledWith('/foo/1', expect.any(Object));

    _jestMockAxios.default.mockError();
  });
  it('should patch by ID', () => {
    patch(1)({
      foo: 'bar'
    });
    expect(_jestMockAxios.default.patch).toHaveBeenCalledWith('/foo/1', {
      foo: 'bar'
    });

    _jestMockAxios.default.mockResponse({
      data: {
        bar: 1
      }
    });

    expect(dispatch).toHaveBeenCalledWith(expect.objectContaining({
      type: _constants.UPDATED,
      data: {
        bar: 1
      }
    }));
  });
  it('should post with decorator', () => {
    const stub = {
      foo: 'bar'
    };
    post(stub);
    expect(_jestMockAxios.default.post).toHaveBeenCalledWith('/foo', stub, expect.any(Object));

    _jestMockAxios.default.mockResponse();

    expect(dispatch).toHaveBeenCalledWith(expect.objectContaining({
      type: _constants.CREATED
    }));
  });
  it('should fail to post', () => {
    post();
    expect(_jestMockAxios.default.post).toHaveBeenCalledWith('/foo', undefined, expect.any(Object));

    _jestMockAxios.default.mockError();
  });
});
describe('useRest configurations', () => {
  it('should throw an error without arguments', () => {
    expect(() => (0, _actions.default)({})).toThrowError();
  });
  it('should call get automatically', () => {
    const resp = {
      data: {
        resources: []
      }
    };
    (0, _actions.default)({
      runOnInit: true,
      url: '/'
    });
    expect(_jestMockAxios.default.get).toHaveBeenCalledWith('/');

    _jestMockAxios.default.mockResponse(resp);

    expect(dispatch).toHaveBeenCalledWith(expect.objectContaining({
      type: _constants.FETCHED,
      ...resp
    }));
  });
  it('should push into the history state', () => {
    const push = jest.fn();
    (0, _actions.default)({
      redirectOnSearch: '/foo',
      location: {
        search: '?search=bar'
      },
      history: {
        push
      },
      url: '/'
    });
    expect(push).toHaveBeenCalledWith('/foo?search=bar');
  });
});