"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _axios = _interopRequireDefault(require("axios"));

var _router = require("@reach/router");

var _lodash = require("lodash");

var _helpers = require("../helpers");

var _reducer = _interopRequireDefault(require("./reducer"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useRest = ({
  url,
  poll,
  redirectOnSearch,
  key,
  pluralized,
  select,
  runOnInit = false,
  decorators = {},
  location = {},
  history = {},
  headers = {}
}) => {
  if (!url) throw new Error('Requires a valid URL');
  const {
    search
  } = location;

  const [state, dispatch] = _react.default.useReducer(_reducer.default, {
    fetching: runOnInit,
    progress: 0
  });

  const call = (type, data = {}, err = {}) => dispatch({
    key,
    data,
    pluralized,
    err,
    type
  });

  const handleRequest = (promise, actions, verb) => promise.then(({
    data
  }) => {
    (0, _lodash.invoke)(decorators, 'get', data);

    const resolver = () => new Promise(res => {
      call(verb, data);
      res(data);
    });

    return poll ? poll().then(resolver) : resolver();
  }).catch(err => Promise.reject((0, _lodash.get)(err, 'response.data')));

  const wrapUpdateFn = (id, verb) => (values, actions) => {
    (0, _lodash.invoke)(decorators, verb, values);
    return handleRequest((0, _lodash.invoke)(_axios.default, verb, (0, _helpers.makePath)([url, id]), values), actions, _constants.UPDATED);
  };

  const invokeFetchingWithQueryString = callWithLoading => (query = '') => {
    if (callWithLoading) call(_constants.FETCHING);
    return _axios.default.get((0, _helpers.formatUrlPath)(url, query, select)).then(({
      data
    }) => {
      (0, _lodash.invoke)(decorators, 'get', data);
      call(_constants.FETCHED, data);
      return Promise.resolve(data);
    }).catch(err => {
      call(_constants.FETCHED, null, err);
      return Promise.reject(err);
    });
  };

  const methods = {
    get: invokeFetchingWithQueryString(true),
    poll: invokeFetchingWithQueryString(false),

    remove(id) {
      return () => _axios.default.delete((0, _helpers.makePath)([url, id])).then(() => {
        call(_constants.DELETED, {
          id
        });
        return poll ? poll() : null;
      }).catch(err => {
        return Promise.reject(err);
      });
    },

    removeBulk(ids = []) {
      return () => _axios.default.delete((0, _helpers.makeQueryPath)(url, ids)).then(() => {
        call(_constants.DELETED_MANY, {
          ids
        });
        return poll ? poll() : null;
      }).catch(err => {
        return err;
      });
    },

    patch(id) {
      const {
        name
      } = methods.patch;
      return wrapUpdateFn(id, name);
    },

    patchBulk(ids, done) {
      return (values, actions) => {
        (0, _lodash.invoke)(decorators, 'patch', values);
        return handleRequest((0, _lodash.invoke)(_axios.default, 'patch', (0, _helpers.makeQueryPath)(url, ids), values), actions, _constants.UPDATED).then(r => {
          if (done) done();
          return r;
        });
      };
    },

    put(id) {
      const {
        name
      } = methods.put;
      return wrapUpdateFn(id, name);
    },

    post(values, actions) {
      const {
        name
      } = methods.post;
      (0, _lodash.invoke)(decorators, name, values);
      return handleRequest(_axios.default.post(url, values, {
        headers
      }), actions, _constants.CREATED);
    }

  };

  _react.default.useEffect(() => {
    _axios.default.interceptors.request.use(function (config) {
      if (config.data instanceof FormData) // eslint-disable-next-line
        config.headers['Content-Type'] = 'multipart/form-data';
      return config;
    });

    const saved = null; // localStorage.getItem(url);

    if (!location.search && saved && saved !== 'null' && saved !== 'undefined') {
      (0, _router.navigate)(`?${saved}`);
    } else if (runOnInit && !redirectOnSearch) {
      methods.get(search);
    } else if (redirectOnSearch && search) {
      const {
        push
      } = history;
      push(`${redirectOnSearch}${search}`);
    }
  }, [search, url]);

  return { ...state,
    ...methods
  };
};

var _default = useRest;
exports.default = _default;